@@ -567,8 +567,8 @@ test_that("constant rate oceanic CS prints correct output when
             replicates <- 1
             verbose <- TRUE
             set.seed(1)
-            expect_output(
-              sim <- DAISIE::DAISIE_sim_cr(time = total_time,
+            expect_message(
+              sim <- DAISIE_sim_cr(time = total_time,
                                            M = mainland_n,
                                            pars = pars,
                                            replicates = replicates,
@@ -586,8 +586,8 @@ test_that("constant rate oceanic IW prints correct output when
             replicates <- 1
             verbose <- TRUE
             set.seed(1)
-            expect_output(
-              sim <- DAISIE::DAISIE_sim_cr(time = total_time,
+            expect_message(
+              sim <- DAISIE_sim_cr(time = total_time,
                                            M = mainland_n,
                                            pars = pars,
                                            replicates = replicates,
@@ -615,7 +615,7 @@ test_that("2 type simulation with divdepmodel = 'CS' verbose run should
             ana_rate_type_2 <- 1.0
             prop_type2_pool <- 0.1
             replicates_apply_type2 <- FALSE
-            expect_output(
+            expect_message(
               sim <- DAISIE_sim_cr(
                 time = island_age,
                 M = n_mainland_species,
@@ -648,7 +648,7 @@ test_that("A divdepmodel = 'GW' run with verbose should print", {
   imm_rate <- 0.01
   ana_rate <- 1.0
   num_guilds <- 5
-  expect_output(
+  expect_message(
     DAISIE_sim_cr(
       time = island_age,
       M = n_mainland_species,
@@ -672,7 +672,7 @@ test_that("2 type, no geodynamics, nonoceanic should give error", {
   set.seed(1)
   prop_type2_pool <- 0.4
   nonoceanic_pars <- c(0.5, 0.5)
-  expect_error(DAISIE::DAISIE_sim_cr(
+  expect_error(DAISIE_sim_cr(
     time = total_time,
     M = M,
     pars = pars,
