@@ -1,10 +1,10 @@
 test_that("use", {
   ps_ana_rate <- 1
   n_immigrants <- 5
-  ana_rate <- DAISIE:::get_ana_rate(
+  ana_rate <- get_ana_rate(
     laa = ps_ana_rate,
     num_immigrants = n_immigrants)
-  created <- DAISIE:::get_ana_rate(
+  created <- get_ana_rate(
     laa = 1,
     num_immigrants = 5)
   expected <- ps_ana_rate * n_immigrants
