@@ -1,9 +1,9 @@
 test_that("use area constant", {
   ps_ext_rate <- 2
   n_species <- 4
-  hyper_pars = DAISIE:::create_hyper_pars(d = 0, x = 0)
+  hyper_pars = create_hyper_pars(d = 0, x = 0)
   area <- 1
-  created <- DAISIE:::get_ext_rate(
+  created <- get_ext_rate(
     mu = ps_ext_rate,
     hyper_pars = hyper_pars,
     extcutoff = 1000,
@@ -17,9 +17,9 @@ test_that("use area constant", {
 test_that("use area variable", {
   ps_ext_rate <- 2
   n_species <- 4
-  hyper_pars = DAISIE:::create_hyper_pars(d = 0.2, x = 0.1)
+  hyper_pars = create_hyper_pars(d = 0.2, x = 0.1)
   area <- 10
-  created <- DAISIE:::get_ext_rate(
+  created <- get_ext_rate(
     mu = ps_ext_rate,
     hyper_pars = hyper_pars,
     extcutoff = 1000,
